### INPUTS, SELECTION

tr <- read.table("data/flood_and_trees.txt", sep="\t", head=T, as.is=T)
ta <- read.table("data/transect.txt", sep="\t", head=T, as.is=T)
oa <- read.table("data/oak_park.txt", sep="\t", head=T, as.is=T)

# check summaries for possible outliers

summary(tr) # OK
summary(ta) # OK
summary(oa) # OK

# pool transect + Oak Park (NA for MAX, 2011 for DAMAGE) + main, select only genera with > 4 trees

oa1 <- oa[,c("DAMAGE.20111130", "GENUS", "HEIGHT.20140621", "MAX")]
names(oa1) <- c("DAMAGE", "GENUS", "HEIGHT", "MAX")
tr0 <- rbind(tr[,c("DAMAGE", "GENUS", "HEIGHT", "MAX")], ta[,c("DAMAGE", "GENUS", "HEIGHT", "MAX")], oa1)
trt <- table(tr0$GENUS)
tr1 <- tr0[tr0$GENUS %in% names(trt[trt>4]),]

### GENERAL STATISTICS

### Tree genera (maybe, replace with dotchart)

summary(tr1)
table(tr1$GENUS)

library(wordcloud)
tr1f <- data.frame(table(tr1$GENUS))
pdf("pics/fig_1_trees_wordcloud.pdf")
wordcloud(tr1f[,1], tr1f[,2], min.freq=0)
dev.off()

# check interactions HEIGHT/MAX (Spearman correlation), HEIGHT/GENUS and MAX/GENUS (Kruskal-Wallis); maybe, remove some outlying genera

cor.test(tr1$HEIGHT, tr1$MAX, method="spearman") # weak but significant
kruskal.test(MAX ~ factor(GENUS), data=tr1) # highly significant
kruskal.test(HEIGHT ~ factor(GENUS), data=tr1) # even higher significant

sort(tapply(tr1$MAX, tr1$GENUS, function(.x) median(.x, na.rm=T))) # no outliers
sort(tapply(tr1$HEIGHT, tr1$GENUS, function(.x) median(.x, na.rm=T))) # Quercus is an outlier but it is hard to remove

### Tree damage: histogram, total number of observations

pdf("pics/fig_2_trees_damage.pdf")
hist(tr1$DAMAGE, 5, main="", xlab="Damage")
dev.off()

### MAIN PART: HEIGHT, MAX, TAXONOMY VS. DAMAGE

## DAMAGE ~ HEIGHT*MAX*GENUS (model with interactions) vs. DAMAGE ~ HEIGHT+MAX+GENUS (without interactions)

# with interactions
dlm1 <- lm(DAMAGE ~ HEIGHT*MAX*GENUS, data=tr1)
summary(dlm1) # only few terms are significant

# without interactions
dlm2 <- lm(DAMAGE ~ HEIGHT+MAX+GENUS, data=tr1)
summary(dlm2) # without interactions, model is much better

AIC(dlm1) # worse
AIC(dlm2) # better
AIC(update(dlm2, ~ . - MAX)) # worse
AIC(update(dlm2, ~ . - GENUS)) # worse
AIC(update(dlm2, ~ . - HEIGHT)) # worse

pdf("pics/fig_3_damage_vs_height.pdf") # Fig. 1?
boxplot(scale(HEIGHT) ~ DAMAGE, data=tr1, xlab="Damage", ylab="Height (scaled)") # scaled height is used becauseit is more robust for observarion errors which undoubtedly were frequent
dev.off()

# damage by genus
sort(tapply(tr1$DAMAGE, tr1$GENUS, function(.x) median(.x, na.rm=T)))

# compare HEIGHT and MAX
cor.test(tr1$DAMAGE, tr1$MAX, method="spearman") # not significant
cor.test(tr1$DAMAGE, tr1$HEIGHT, method="spearman") # significant but do mind interactions

## DAMAGE vs. taxonomy

# vs. GENUS: (1) Kruskal-Wallis, (2) post hoc like PMCMR::posthoc.kruskal.nemenyi.test(), npmc::npmc(), nparcomp::mctp() or simply pairwise.wilcox.test()

kruskal.test(DAMAGE ~ factor(GENUS), data=tr1) # of course, this is significant

library(PMCMR) # post hoc comparisons (see help(package="PMCMR"))
posthoc.kruskal.nemenyi.test(tr1$DAMAGE, factor(tr1$GENUS)) # only few differences are significant or almost significant

# vs. NATIVE: if significant, do not forget to check HEIGHT interaction (MAX interaction is unfortunately unavoidable because of its fully accidental nature)

NATIVE <- c("Fraxinus","Juniperus","Populus","Prunus","Quercus","Ulmus")
tNATIVE <- ifelse(tr1$GENUS %in% NATIVE, "Native", "Introduced")
wilcox.test(DAMAGE ~ tNATIVE, data=tr1) # not significant

# vs. PINACEAE: "

PINACEAE <- c("Picea","Pinus")
tPINACEAE <- ifelse(tr1$GENUS %in% PINACEAE, "Pinaceae", "Other")
wilcox.test(DAMAGE ~ tPINACEAE, data=tr1) # not significant

# vs. CONIFERS: "

CONIFERS <- c("Picea","Pinus","Juniperus")
tCONIFERS <- ifelse(tr1$GENUS %in% CONIFERS, "Conifers", "Angiosperms")
wilcox.test(DAMAGE ~ tCONIFERS, data=tr1) # significant
wilcox.test(HEIGHT ~ tCONIFERS, data=tr1) # at the same time, interaction with height is not sifgnificant -- good!

pdf("pics/fig_4_damage_vs_conifers.pdf")
boxplot(DAMAGE ~ tCONIFERS, data=tr1, varwidth=T)
dev.off()

# vs. ROSACEAE: "

ROSACEAE <- c("Pyrus","Prunus")
tROSACEAE <- ifelse(tr1$GENUS %in% ROSACEAE, "Rosaceae", "non-Rosaceae")
wilcox.test(DAMAGE ~ tROSACEAE, data=tr1) # significant
wilcox.test(HEIGHT ~ tROSACEAE, data=tr1) # significant -- interactions present

### TRANSECT: DAMAGE vs. MAX just for one genus (Pyrus) just in one place (8th St); we need that because HEIGHT and MAX are both interacting with GENUS

# DAMAGE ~ MAX; HEIGHT is not checked because trees in transect have similar sizes

talm <- lm(DAMAGE ~ MAX, data=ta)
summary(talm) # significant with relevant R squared

tanew <- data.frame(MAX=seq(min(ta$MAX, na.rm=T), max(ta$MAX, na.rm=T), along.with=ta$MAX)) # for confidence intervals
tapred <- predict(talm, interval="confidence", newdata=tanew)

pdf("pics/fig_5_transect_damage_vs_max.pdf") # Fig. 2?
plot(jitter(DAMAGE) ~ MAX, data=ta, xlab="Maximum level of water, m", ylab="Damage") # jitter() is used to visualize overlapped points
abline(talm)
matlines(tanew$MAX, tapred, col="black", lty=c(0,2,2)) # with 95% confidence intervals
dev.off()

### OAK PARK: YEARLY TREND

# use median, try also Friedman test (because these are repeated measurewents)

oa2 <- oa[,c("DAMAGE.20111130", "DAMAGE.20120510", "DAMAGE.20140621")] # select only damages for three years
apply(oa2, 2, function(.x) median(.x, na.rm=T)) # decrease trend
friedman.test(as.matrix(oa2)) # not significant

